import agros2d as a2d

# problem
problem = a2d.problem(clear = True)
problem.coordinate_type = "planar"
problem.mesh_type = "triangle"

# fields
# heat
heat = a2d.field("heat")
heat.analysis_type = "steadystate"
heat.matrix_solver = "mumps"
heat.number_of_refinements = 1
heat.polynomial_order = 2
heat.adaptivity_type = "disabled"
heat.solver = "linear"

geometry = a2d.geometry



# materials
heat.add_material("AT-H80 expand�lt polisztirolhab_0", {"heat_conductivity" : 0.0400, "heat_volume_heat" : 0, "heat_velocity_x" : 0, "heat_velocity_y" : 0, "heat_velocity_angular" : 0, "heat_density" : 0, "heat_specific_heat" : 0})
heat.add_material("B 30-as t�gla falazat_0", {"heat_conductivity" : 0.6400, "heat_volume_heat" : 0, "heat_velocity_x" : 0, "heat_velocity_y" : 0, "heat_velocity_angular" : 0, "heat_density" : 0, "heat_specific_heat" : 0})

# boundaries
heat.add_boundary("Neumann", "heat_heat_flux", {"heat_heat_flux" : 0, "heat_convection_heat_transfer_coefficient" : 0.0000, "heat_convection_external_temperature" : 273.15, "heat_radiation_emissivity" : 0, "heat_radiation_ambient_temperature" : 273.15})
heat.add_boundary("kulso", "heat_heat_flux", {"heat_heat_flux" : 0, "heat_convection_heat_transfer_coefficient" : 25.0000, "heat_convection_external_temperature" : 258.15, "heat_radiation_emissivity" : 0, "heat_radiation_ambient_temperature" : 258.15})
heat.add_boundary("belso", "heat_heat_flux", {"heat_heat_flux" : 0, "heat_convection_heat_transfer_coefficient" : 7.7000, "heat_convection_external_temperature" : 293.15, "heat_radiation_emissivity" : 0, "heat_radiation_ambient_temperature" : 293.15})

# geometry edges
geometry.add_edge(2.5000, -0.0500, 0.0000, -0.0500)
geometry.add_edge(0.0000, -0.0500, 0.0000, -0.0000, boundaries = {"heat" : "Neumann"})
geometry.add_edge(0.0000, -0.0000, 2.5000, -0.0000, boundaries = {"heat" : "kulso"})
geometry.add_edge(2.5000, -0.0000, 2.5000, -0.0500, boundaries = {"heat" : "Neumann"})
geometry.add_edge(1.0000, -0.3500, 0.0000, -0.3500, boundaries = {"heat" : "belso"})
geometry.add_edge(0.0000, -0.3500, 0.0000, -0.0500, boundaries = {"heat" : "Neumann"})
geometry.add_edge(2.5000, -0.0500, 2.5000, -0.3500, boundaries = {"heat" : "Neumann"})
geometry.add_edge(2.5000, -0.3500, 1.5000, -0.3500, boundaries = {"heat" : "belso"})
geometry.add_edge(1.5000, -0.3500, 1.5000, -0.2500, boundaries = {"heat" : "belso"})
geometry.add_edge(1.5000, -0.2500, 1.0000, -0.2500, boundaries = {"heat" : "belso"})
geometry.add_edge(1.0000, -0.2500, 1.0000, -0.3500, boundaries = {"heat" : "belso"})

# areas
geometry.add_label(1.2500, -0.0250, materials = {"heat" : "AT-H80 expand�lt polisztirolhab_0"})
geometry.add_label(1.2500, -0.2000, materials = {"heat" : "B 30-as t�gla falazat_0"})
sumAU = 1.3237;
sumAUString = "1.5000 m * 0.5295 W/m2K + 1.0000 m * 0.5295 W/m2K";
dt = 35.0;
InnerBoundaris = [4,7,8,9,10];
OuterBoundaris = [2];

problem.solve();

# Calculate average heatloss and pszi

qi = heat.surface_integrals(InnerBoundaris)
qe = heat.surface_integrals(OuterBoundaris)
q = (abs(qi["f"])+abs(qe["f"]))/2
L2 = q/dt;
pszi = L2 - sumAU

FormatString = "qi: {:.2f} W/m\nqe: {:.2f} W/m\nL2d: {:.3f} W/mK\nA*U: {:s} = {:.3f} W/mK\nPszi: {:.3f} W/mK\n"
print(FormatString.format(abs(qi["f"]), abs(qe["f"]), L2, sumAUString, sumAU, pszi))

# Result visualisation

v2 = a2d.view.post2d
v2.scalar_view_parameters["variable"] = "heat_temperature_degrees"
v2.scalar_view_parameters["auto_range"] = 0
v2.scalar_view_parameters["range_min"] = -15
v2.scalar_view_parameters["range_max"] = 20
v2.vectors = 1
v2.activate()

