import agros2d as a2d

# problem
problem = a2d.problem(clear = True)
problem.coordinate_type = "planar"
problem.mesh_type = "triangle"

# fields
# heat
heat = a2d.field("heat")
heat.analysis_type = "steadystate"
heat.matrix_solver = "mumps"
heat.number_of_refinements = 1
heat.polynomial_order = 2
heat.adaptivity_type = "disabled"
heat.solver = "linear"

geometry = a2d.geometry



# materials
heat.add_material("Cementvakolat_0", {"heat_conductivity" : 0.9300, "heat_volume_heat" : 0, "heat_velocity_x" : 0, "heat_velocity_y" : 0, "heat_velocity_angular" : 0, "heat_density" : 0, "heat_specific_heat" : 0})
heat.add_material("B 30-as t�gla falazat_0", {"heat_conductivity" : 0.6400, "heat_volume_heat" : 0, "heat_velocity_x" : 0, "heat_velocity_y" : 0, "heat_velocity_angular" : 0, "heat_density" : 0, "heat_specific_heat" : 0})

# boundaries
heat.add_boundary("Neumann", "heat_heat_flux", {"heat_heat_flux" : 0, "heat_convection_heat_transfer_coefficient" : 0.0000, "heat_convection_external_temperature" : 273.15, "heat_radiation_emissivity" : 0, "heat_radiation_ambient_temperature" : 273.15})
heat.add_boundary("Inside_7,7", "heat_heat_flux", {"heat_heat_flux" : 0, "heat_convection_heat_transfer_coefficient" : 7.7000, "heat_convection_external_temperature" : 293.15, "heat_radiation_emissivity" : 0, "heat_radiation_ambient_temperature" : 293.15})
heat.add_boundary("OutSide_25", "heat_heat_flux", {"heat_heat_flux" : 0, "heat_convection_heat_transfer_coefficient" : 25.0000, "heat_convection_external_temperature" : 258.15, "heat_radiation_emissivity" : 0, "heat_radiation_ambient_temperature" : 258.15})

# geometry edges
geometry.add_edge(0.0000, -0.0100, 0.0000, -0.0000, boundaries = {"heat" : "Inside_7,7"})
geometry.add_edge(0.0000, -0.0000, 1.3200, -0.0000, boundaries = {"heat" : "Inside_7,7"})
geometry.add_edge(1.3200, -0.0000, 1.3200, -0.0100, boundaries = {"heat" : "Neumann"})
geometry.add_edge(1.3200, -0.0100, 0.0100, -0.0100)
geometry.add_edge(0.0000, -1.3200, 0.0000, -0.0100, boundaries = {"heat" : "Inside_7,7"})
geometry.add_edge(0.0100, -0.0100, 0.0000, -0.0100)
geometry.add_edge(0.0100, -0.3100, 0.0100, -1.3200)
geometry.add_edge(0.0100, -1.3200, 0.0000, -1.3200, boundaries = {"heat" : "Neumann"})
geometry.add_edge(0.0100, -0.0100, 0.0100, -0.3100)
geometry.add_edge(1.3200, -0.0100, 1.3200, -0.3100, boundaries = {"heat" : "Neumann"})
geometry.add_edge(1.3200, -0.3100, 0.3100, -0.3100)
geometry.add_edge(0.3100, -0.3100, 0.0100, -0.3100)
geometry.add_edge(0.3100, -0.3200, 0.3100, -1.3200)
geometry.add_edge(0.3100, -1.3200, 0.0100, -1.3200, boundaries = {"heat" : "Neumann"})
geometry.add_edge(0.3100, -0.3100, 0.3100, -0.3200)
geometry.add_edge(1.3200, -0.3100, 1.3200, -0.3200, boundaries = {"heat" : "Neumann"})
geometry.add_edge(1.3200, -0.3200, 0.3200, -0.3200, boundaries = {"heat" : "OutSide_25"})
geometry.add_edge(0.3200, -0.3200, 0.3100, -0.3200)
geometry.add_edge(0.3200, -0.3200, 0.3200, -1.3200, boundaries = {"heat" : "OutSide_25"})
geometry.add_edge(0.3200, -1.3200, 0.3100, -1.3200, boundaries = {"heat" : "Neumann"})

# areas
geometry.add_label(0.6600, -0.0050, materials = {"heat" : "Cementvakolat_0"})
geometry.add_label(0.0050, -0.6650, materials = {"heat" : "Cementvakolat_0"})
geometry.add_label(0.6650, -0.1600, materials = {"heat" : "B 30-as t�gla falazat_0"})
geometry.add_label(0.1600, -0.8150, materials = {"heat" : "B 30-as t�gla falazat_0"})
geometry.add_label(0.8150, -0.3150, materials = {"heat" : "Cementvakolat_0"})
geometry.add_label(0.3150, -0.8200, materials = {"heat" : "Cementvakolat_0"})
sumAU = 0.0100 * 1.5149 + 1.3200 * 1.5149 + 1.3100 * 1.5149;
sumAUString = "0.0100 m * 1.5149 W/m2K + 1.3200 m * 1.5149 W/m2K + 1.3100 m * 1.5149 W/m2K";
dt = 35;
InnerBoundaris = [0,1,4];
OuterBoundaris = [16,18];

problem.solve();

# Calculate average heatloss and pszi

qi = heat.surface_integrals(InnerBoundaris)
qe = heat.surface_integrals(OuterBoundaris)
q = (abs(qi["f"])+abs(qe["f"]))/2
L2 = q/dt;
pszi = L2 - sumAU

FormatString = "qi: {:.2f} W/m\nqe: {:.2f} W/m\nL2d: {:.3f} W/mK\nA*U: {:s} = {:.3f} W/mK\nPszi: {:.3f} W/mK\n"
print(FormatString.format(abs(qi["f"]), abs(qe["f"]), L2, sumAUString, sumAU, pszi))

# Result visualisation

v2 = a2d.view.post2d
v2.scalar_view_parameters["variable"] = "heat_temperature_degrees"
v2.scalar_view_parameters["auto_range"] = 0
v2.scalar_view_parameters["range_min"] = -15
v2.scalar_view_parameters["range_max"] = 20
v2.vectors = 1
v2.activate()

